<?php

if (!defined('ABSPATH')) {
	header('Status: 403 Forbidden');
	header('HTTP/1.1 403 Forbidden');
	exit;
}

/**
 * XElementor Image Accordion Elementor Widget
 *
 * @since 1.0.0
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Widget_Base;
use Elementor\Repeater;
use Elementor\Utils;

class Elementor_XEl_Image_Accordion extends \Elementor\Widget_Base
{

	/**
	 * Load scripts.
	 *
	 * Load script and stylesheet for the plugin.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function __construct($data = [], $args = null)
	{
		parent::__construct($data, $args);

		wp_register_style('xel-image-accordion-stylesheet', XElImageAccordion()->plugin_url() . '/assets/css/styles' . (is_rtl() ? '-rtl' : '') . '.css', false, XElImageAccordion()->version());
	}

	public function get_style_depends()
	{
		return ['xel-image-accordion-stylesheet'];
	}

	/**
	 * Get widget name.
	 *
	 * Retrieve this widget name.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'xel-image-accordion';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve this widget title.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Image Accordion', 'xel-image-accordion');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve this widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-slider-3d';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories this widget belongs to.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return array('general');
	}

	/**
	 * Register this widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__('Element Controls', 'xel-image-accordion'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		// Accordion Type
		$this->add_responsive_control(
			'tabsType',
			[
				'label' => esc_html__('Accordion Type', 'xel-image-accordion'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'row' => esc_html__('Horizontal', 'xel-image-accordion'),
					'column' => esc_html__('Vertical', 'xel-image-accordion'),
				],
				'selectors' => [
					'{{WRAPPER}} .xel-image-accordion' => 'flex-direction: {{tabsType}};',
				],
				'default' => 'row',
			]
		);

		// Alignment
		$this->add_responsive_control(
			'tabsAlignX',
			[
				'label' => esc_html__('Alignment', 'xel-image-accordion'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__('Left', 'xel-image-accordion'),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'xel-image-accordion'),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'xel-image-accordion'),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .xel-image-accordion--content' => 'text-align: {{tabsAlignX}};',
				],
				'toggle' => true,
				'label_block' => false,
			]
		);

		// Alignment
		$this->add_responsive_control(
			'tabsAlignY',
			[
				'label' => esc_html__('Alignment', 'xel-image-accordion'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__('Top', 'xel-image-accordion'),
						'icon' => 'eicon-align-start-v',
					],
					'center' => [
						'title' => esc_html__('Middle', 'xel-image-accordion'),
						'icon' => 'eicon-align-center-v',
					],
					'flex-end' => [
						'title' => esc_html__('Bottom', 'xel-image-accordion'),
						'icon' => 'eicon-align-end-v',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .xel-image-accordion--content' => 'align-items: {{tabsAlignY}};',
				],
				'toggle' => true,
				'label_block' => false,
			]
		);

		// Height
		$this->add_responsive_control(
			'tabsHeight',
			[
				'label' => esc_html__('Height', 'xel-image-accordion'),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => 'px',
				],
				'size_units' => ['px', 'vw', 'rem'],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'rem' => [
						'min' => 1,
						'max' => 100,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .xel-image-accordion' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// HTML tag
		$this->add_control(
			'tag',
			[
				'label' => esc_html__('HTML Tag', 'xel-image-accordion'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'div',
					'span' => 'span',
				],
				'default' => 'h2',
			]
		);

		// Items
		$repeater = new Repeater();

		$repeater->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'tabImage',
				'label' => esc_html__('Image', 'xel-image-accordion'),
				'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
			]
		);

		$repeater->add_control(
			'tabTitle',
			[
				'label' => esc_html__('Title', 'xel-image-accordion'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title', 'xel-image-accordion'),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'tabContent',
			[
				'label' => esc_html__('Content', 'xel-image-accordion'),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__('Content', 'xel-image-accordion'),
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => esc_html__('Link', 'xel-image-accordion'),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__('https://xelementor.com', 'xel-image-accordion'),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__('Items', 'xel-image-accordion'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tabTitle' => esc_html__('Title', 'xel-image-accordion'),
						'tabContent' => esc_html__('Content', 'xel-image-accordion'),
					],
					[
						'tabTitle' => esc_html__('Title', 'xel-image-accordion'),
						'tabContent' => esc_html__('Content', 'xel-image-accordion'),
					],
				],
				'titleField' => '{{{ tabTitle }}}',
			]
		);

		$this->end_controls_section();

		// Style
		$this->start_controls_section('styles', ['label' => esc_html__('Styles', 'xel-image-accordion'), 'tab' => Controls_Manager::TAB_STYLE,]);

		// Heading
		$this->start_controls_tabs('heading');

		$this->start_controls_tab(
			'tab_heading',
			[
				'label' => esc_html__('Heading', 'xel-image-accordion')
			]
		);

		// Color
		$this->add_control(
			'color',
			[
				'label' => esc_html__('Color', 'xel-image-accordion'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .xel-image-accordion--title' => 'color: {{VALUE}}',
				],
			]
		);

		// Typography
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'label' => esc_html__('Typography', 'xel-image-accordion'),
				'selector' => '{{WRAPPER}} .xel-image-accordion--title',
			]
		);

		// Shadow
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'shadow',
				'label' => esc_html__('Shadow', 'xel-image-accordion'),
				'selector' => '{{WRAPPER}} .xel-image-accordion--title',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_content',
			[
				'label' => esc_html__('Content', 'xel-image-accordion')
			]
		);

		// Color
		$this->add_control(
			'colorContent',
			[
				'label' => esc_html__('Color', 'xel-image-accordion'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .xel-image-accordion--text-content' => 'color: {{VALUE}}',
				],
			]
		);

		// Typography
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typographyContent',
				'label' => esc_html__('Typography', 'xel-image-accordion'),
				'selector' => '{{WRAPPER}} .xel-image-accordion--text-content',
			]
		);

		// Shadow
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'shadowContent',
				'label' => esc_html__('Shadow', 'xel-image-accordion'),
				'selector' => '{{WRAPPER}} .xel-image-accordion--text-content',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_item',
			[
				'label' => esc_html__('Item', 'xel-image-accordion')
			]
		);

		// Shadow
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'itemShadow',
				'selector' => '{{WRAPPER}} .xel-image-accordion--content-parent',
			]
		);

		// Border
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'itemBorder',
				'selector' => '{{WRAPPER}} .xel-image-accordion--content-parent',
				'separator' => 'before',
			]
		);

		// Border radius
		$this->add_responsive_control(
			'itemBorderRadius',
			[
				'label' => esc_html__('Border Radius', 'xel-image-accordion'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px', '%'],
				'separator' => 'after',
				'selectors' => [
					'{{WRAPPER}} .xel-image-accordion--content-parent' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	/**
	 * Render this widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 */
	protected function render()
	{
		$id = 'xel-' . $this->get_id();
		$settings = $this->get_settings_for_display();

?>
		<div id="<?php esc_attr_e($id); ?>" class="xel-image-accordion">
			<?php
			if (is_array($settings['tabs'])) {
				foreach ($settings['tabs'] as $n => $tab) {
					$url = isset($tab['link']['url']) ? $tab['link']['url'] : "";
			?>
					<div class="xel-image-accordion--content-parent elementor-repeater-item-<?php echo esc_attr($tab['_id']); ?>">
						<?php
						if (!empty($url)) {
						?>
							<a href="<?php echo esc_url($url); ?>">
							<?php
						}
							?>
							<div class="xel-image-accordion--content">
								<div class="xel-image-accordion--content-holder">
									<div>
										<<?php esc_attr_e($settings["tag"]); ?> class="xel-image-accordion--title">
											<?php $this->print_unescaped_setting('tabTitle', 'tabs', $n); ?>
										</<?php esc_attr_e($settings["tag"]); ?>>
										<div class="xel-image-accordion--text-content">
											<?php $this->print_text_editor($tab['tabContent']); ?>
										</div>
									</div>
								</div>
							</div>
							<?php
							if (!empty($url)) {
							?>
							</a>
						<?php
							}
						?>
					</div>
			<?php
				}
			}
			?>
		</div>
<?php
	}
}
